BetaClass
=========

.. badges:: stability:beta stability:new area:core

A new class still in the beta programme - the API may change.

.. py:class:: BetaClass(config)

   Initialise with a configuration mapping.

   .. badges:: stability:beta area:core

   .. py:method:: run()

      Execute the configured job.

      .. badges:: stability:beta stability:experimental area:core
